==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_functions/mp0356_001/MP0356_RemoveEquipmentFromStructure_001.java <==

package net.datastream.schemas.mp_functions.mp0356_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;choice>
 *           &lt;element name="FromAllParents" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0356_001}ParentEquipment" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Remove" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="EquipmentHierarchy" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentid",
    "fromAllParents",
    "parentEquipment"
})
@XmlRootElement(name = "MP0356_RemoveEquipmentFromStructure_001")
public class MP0356_RemoveEquipmentFromStructure_001 {

    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "FromAllParents")
    protected String fromAllParents;
    @XmlElement(name = "ParentEquipment")
    protected ParentEquipment parentEquipment;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété fromAllParents.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFromAllParents() {
        return fromAllParents;
    }

    /**
     * Définit la valeur de la propriété fromAllParents.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFromAllParents(String value) {
        this.fromAllParents = value;
    }

    /**
     * Obtient la valeur de la propriété parentEquipment.
     * 
     * @return
     *     possible object is
     *     {@link ParentEquipment }
     *     
     */
    public ParentEquipment getParentEquipment() {
        return parentEquipment;
    }

    /**
     * Définit la valeur de la propriété parentEquipment.
     * 
     * @param value
     *     allowed object is
     *     {@link ParentEquipment }
     *     
     */
    public void setParentEquipment(ParentEquipment value) {
        this.parentEquipment = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REMOVE;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EQUIPMENT_HIERARCHY;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_functions/mp0356_001/MP0356_RemoveEquipmentFromStructure_001.java <==

package net.datastream.schemas.mp_functions.mp0356_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;choice>
 *           &lt;element name="FromAllParents" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0356_001}ParentEquipment" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Remove" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="EquipmentHierarchy" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentid",
    "fromAllParents",
    "parentEquipment"
})
@XmlRootElement(name = "MP0356_RemoveEquipmentFromStructure_001")
public class MP0356_RemoveEquipmentFromStructure_001 {

    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "FromAllParents")
    protected String fromAllParents;
    @XmlElement(name = "ParentEquipment")
    protected ParentEquipment parentEquipment;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the fromAllParents property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFromAllParents() {
        return fromAllParents;
    }

    /**
     * Sets the value of the fromAllParents property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFromAllParents(String value) {
        this.fromAllParents = value;
    }

    /**
     * Gets the value of the parentEquipment property.
     * 
     * @return
     *     possible object is
     *     {@link ParentEquipment }
     *     
     */
    public ParentEquipment getParentEquipment() {
        return parentEquipment;
    }

    /**
     * Sets the value of the parentEquipment property.
     * 
     * @param value
     *     allowed object is
     *     {@link ParentEquipment }
     *     
     */
    public void setParentEquipment(ParentEquipment value) {
        this.parentEquipment = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REMOVE;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EQUIPMENT_HIERARCHY;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
